import cv2 
from numpy import *
from matplotlib import pyplot as plt
import scipy.misc as sc
import math
import cv2.cv as cv
import PIL
from PIL import Image

# Set user variables here
voting_threshold = 20
# These are coordinate transform variables obtained from the point probe routine

# Trailing edge position in pixels
ky1 = 491.786
kx1 = 1548

# Sacling factor 
ky2 = 0.148936
kx2 = 0.148620

#flowvis = cv2.imread('streaklines.png')    # Wide Aperture with UV and without LED - used by Tarek
flowvis = cv2.imread('casing.png') 

# Set up file for output
f = open('%d Threshold.txt' % voting_threshold, 'w')
f.write('ax_mm,tan_mm,alpha,v_ax,v_tan\n')

mask = zeros(flowvis.shape, dtype=uint8)
roi_corners = array([[(30,195),(30,1925),(4090,1925),(1580,195)]], dtype=int32)
# fill the ROI so it doesn't get wiped out when the mask is applied
channel_count = flowvis.shape[2]  # i.e. 3 or 4 depending on your image
ignore_mask_color = (255,)*channel_count
cv2.fillPoly(mask, roi_corners, ignore_mask_color)
# apply the mask
masked = cv2.bitwise_and(flowvis, mask)


# Output some equalised images for use in the paper
# Some fiddling to improve the output contrast
# Tarek used masked but I think a equalised gray scale is better
grayxy = cv2.cvtColor(masked,cv2.COLOR_BGR2GRAY)
equ = cv2.equalizeHist(grayxy)
cv2.imwrite('%d_equ.png'% voting_threshold,equ)

cropped = masked
###################################
#To view the cropped area
grayx = cv2.cvtColor(cropped,cv2.COLOR_BGR2GRAY)
blurx = cv2.GaussianBlur(grayx,(21,21),0)
ret,thresh = cv2.threshold(blurx,50,255,0)
contours, hierarchy = cv2.findContours(thresh,cv2.RETR_TREE,cv2.CHAIN_APPROX_SIMPLE)
imgx = cv2.drawContours(cropped,contours,-1,(0,0,0),2)

###################################
cellsize_r = (cropped.shape[0]/85)
cellsize_c = (cropped.shape[1]/119)

for r in range(0,cropped.shape[0] - cellsize_r, cellsize_r):
    for c in range(0,cropped.shape[1] - cellsize_c, cellsize_c):
        img = cropped[r:r+cellsize_r,c:c+cellsize_c]
        gray = cv2.cvtColor(img,cv2.COLOR_BGR2GRAY)
        #blur12 = cv2.GaussianBlur(gray,(3,3),0) # LPF using Gaussian filter
        blur = cv2.bilateralFilter(gray,7,11,9) # LPF using Bilateral filter
        sobel_x = cv2.Sobel(blur,cv2.CV_8U,0,1,ksize=3)
        edges = cv2.Canny(sobel_x,0,65,1)
        lines = cv2.HoughLines(edges,1,pi/180,voting_threshold)
        if lines is not None:
            for rho,theta in lines[0]:
                angle = theta
                position = rho
                a = cos(angle)
                b = sin(angle)
                x0 = a*position
                y0 = b*position
                x1 = int(x0 + 1000*(-b))
                y1 = int(y0 + 1000*(a))
                x2 = int(x0 - 1000*(-b))
                y2 = int(y0 - 1000*(a))
                cv2.line(img,(x1,y1),(x2,y2),(255,0,0),2)
                domin = x2-x1
                if domin != 0:
                    try:
                        tan_alpha = float((y2-y1))/(x2-x1)
                    except ZeroDivisionError:
                            tan_alpha = 0
                alpha = float(-math.degrees(math.atan(tan_alpha)))
                print "Alpha: %f, Angle: %f, Angle+Alpha %f" % (alpha,math.degrees(angle),(math.degrees(angle)+alpha))
                x_g = x0+c
                y_g = y0+r
                # print 'Region 1 (x,y,alpha):',(int(x_g),int(y_g),int(alpha))


		# Convert to cascade coordinates axial and tangential
		# and also from pixels to mm, y = axial, x = tangential
		# (requires conversion factors from point probe routine)
		tan_mm = (x_g - kx1)*kx2
		ax_mm = -1 * (y_g - ky1)*ky2
		v_x = math.cos(math.radians(alpha))
		v_y = math.sin(math.radians(alpha))
		v_ax = v_y
		v_tan = v_x
                
		# f.write('%f,%f,%f,%f,%f\n' % (ax_mm, tan_mm, alpha, v_ax, v_tan))

                # Easier just to use angle from the code than the
                # alpha Tarek developed - not sure why he didn't just
                # use the angle
                f.write('%f,%f,%f,%f,%f\n' % (ax_mm, tan_mm, math.degrees(angle), v_ax, v_tan))
                #print int(alpha)
                
for r in range(0,cropped.shape[0] - cellsize_r, cellsize_r):
    for c in range(0,cropped.shape[1] - cellsize_c, cellsize_c):
        img = cropped[r:r+cellsize_r,c:c+cellsize_c]
        gray = cv2.cvtColor(img,cv2.COLOR_BGR2GRAY)
        #blur12 = cv2.GaussianBlur(gray,(3,3),0) # LPF using Gaussian filter
        blur = cv2.bilateralFilter(gray,7,11,9) # LPF using Bilateral filter
        sobel_y = cv2.Sobel(blur,cv2.CV_8U,1,0,ksize=5)
        edges = cv2.Canny(sobel_y,0,65,1)
        lines = cv2.HoughLines(edges,1,pi/180,voting_threshold)
        if lines is not None:
            for rho,theta in lines[0]:
                angle = theta
                position = rho
                a = cos(angle)
                b = sin(angle)
                x0 = a*position
                y0 = b*position
                x1 = int(x0 + 1000*(-b))
                y1 = int(y0 + 1000*(a))
                x2 = int(x0 - 1000*(-b))
                y2 = int(y0 - 1000*(a))
                cv2.line(img,(x1,y1),(x2,y2),(255,0,0),2)
                domin = x2-x1
                if domin != 0:
                    try:
                        tan_alpha = float((y2-y1))/(x2-x1)
                    except ZeroDivisionError:
                            tan_alpha = 0
                alpha = float(-math.degrees(math.atan(tan_alpha)))
                x_g = x0+c
                y_g = y0+r

                

		# Convert to cascade coordinates axial and tangential
		# and also from pixels to mm, y = axial, x = tangential
		# (requires conversion factors from point probe routine)
		tan_mm = (x_g - kx1)*kx2
		ax_mm = -1* (y_g - ky1)*ky2
		# alpha is measured counter clockwise
		v_x = math.cos(math.radians(alpha))
		v_y = math.sin(math.radians(alpha))
		v_ax = v_y
		v_tan = v_x
		#f.write('%f,%f,%f,%f,%f\n' % (ax_mm, tan_mm, alpha, v_ax, v_tan))
                f.write('%f,%f,%f,%f,%f\n' % (ax_mm, tan_mm, math.degrees(angle), v_ax, v_tan))
                #print int(alpha)

f.close()



# Output with OpenCV
screen_res = 1496., 1000.
scale_width = screen_res[0] / masked.shape[1]
scale_height = screen_res[1] / masked.shape[0]
scale = min(scale_width, scale_height)
window_width = int(masked.shape[1] * scale)
window_height = int(masked.shape[0] * scale)

# create a named window object
cv2.namedWindow('Vectors', cv2.WINDOW_NORMAL)
cv2.resizeWindow('Vectors', window_width, window_height)

cv2.circle(masked,(int(kx1),int(ky1)),10,4,thickness=10, lineType=8, shift=0)
#cv2.imshow('Vectors',masked)
#k = cv2.waitKey(0) & 0xFF
#if k == 27:     # Press ESC to end
#    cv2.destroyAllWindows()
cv2.imwrite('%dThreshold.png' % voting_threshold,masked)



