"""
Plot image processed lines compared to blades
"""

import matplotlib.pyplot as plt
import numpy as np
from scipy import ndimage

# Set user variables here
voting_threshold = 20

# Read in blade geometry coordinates
blade = np.genfromtxt('bladegeometry.txt', delimiter=',', skip_header=1,
                     names=['axial', 'tan'])

# Read in image with blue vectors on
image = plt.imread('%dThreshold.png' % voting_threshold)
rotate_image = ndimage.rotate(image,-90)

# Use extent keyword of imshow to specify the scale and origin of the image
# extent = [left, right, bottom, top]
# Elements of extent should be specified in data units which need to be calculated
# using the output of "Colour and Location Probe.py"


# Plot image with blue vectors on
plt.imshow(rotate_image,origin='lower', zorder=0, extent=[-225.1, 73.4, -232, 215])

# Plot some blade outlines over the top
plt.plot(blade['axial'],blade['tan'],'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'g-',lw=3)

# Put on the measured location of the saddle point
# X -180.56
# Y -102.81

plt.scatter(-180.56, -102.81, s=10, c='blue', alpha=0.5)
plt.annotate('Saddle\nPoint',color='white', xy=(-180.56,102.81), xycoords='data',
                xytext=(-100,95), textcoords='data',
                arrowprops=dict(arrowstyle="->",color='white',linewidth=2)
                )

plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")
# Set some limits to crop the image
plt.xlim(-200,25)
plt.ylim(-225,125)

plt.savefig('%dThreshold_withblade.png' % voting_threshold, bbox_inches='tight',dpi=300)
plt.show()

