"""
Plot shear stress contours compared to blades
"""

import matplotlib.pyplot as plt
import numpy as np
from scipy import ndimage
from scipy import interpolate

# Set user variables here
voting_threshold = 1000
cfd_file = 'WallShearTipClearance.csv'

# Read in blade geometry coordinates
blade = np.genfromtxt('bladegeometry.txt', delimiter=',', skip_header=1,
                     names=['axial', 'tan'])

# Read in shear stress data
hub = np.genfromtxt('./CFD/%s' % cfd_file, delimiter=',', skip_header=7,
                     names=['axial', 'tan','radial','tau'])


# Set up a regular grid of interpolation points
x = hub['axial']*1000
y = hub['tan']*1000
phi = hub['tau']

# Add periodic data (put in four sets to get good data - bit of a hack!)
# There is probably a better way of doing this.....
xl = np.append(x,x)
yl = np.append(y-191,y-382)
phil = np.append(phi,phi)

xu = np.append(x,x)
yu = np.append(y+191,y)
phiu = np.append(phi,phi)

x = np.append(xu,xl)
y = np.append(yu,yl)
phi = np.append(phiu,phil)

xi, yi = np.linspace(x.min(), x.max(), 1000), np.linspace(y.min(), y.max(), 1000)
xi, yi = np.meshgrid(xi, yi)

# Interpolate; there's also method='cubic' for 2-D data such as here
zi = interpolate.griddata((x, y), phi, (xi, yi), method='linear')

plt.imshow(zi, vmin=phi.min(), vmax=phi.max(), origin='lower',
           extent=[x.min(), x.max(), y.min(), y.max()],zorder=0)
plt.colorbar(label = "Shear Stress /  [Pa]")



# Plot some blade outlines over the top
plt.plot(blade['axial'],blade['tan'],'k-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'k-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'k-',lw=3)
plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")

# Put a label on for shear stress,
plt.annotate('Max.\nShear',color='white', xy=(-67.58,-67.57), xycoords='data',
                xytext=(-100,75), textcoords='data',
                arrowprops=dict(arrowstyle="->",color='white',linewidth=2)
                )

# Set some limits to crop the image
plt.xlim(-200,25)
plt.ylim(-225,125)

plt.savefig('%s_tau.png' % cfd_file, bbox_inches='tight',dpi=300)
plt.show()

