"""
Plot image processed lines compared to blades
"""

import matplotlib.pyplot as plt
import numpy as np
from scipy import ndimage

# Read in blade geometry coordinates
blade = np.genfromtxt('bladegeometry.txt', delimiter=',', skip_header=1,
                     names=['axial', 'tan'])

# Read in image 
# image = plt.imread('Maxiumum_Wall_Shear_Point_Casing.png')
image = plt.imread('equ.png')
rotate_image = ndimage.rotate(image,-90)

# Use extent keyword of imshow to specify the scale and origin of the image
# extent = [left, right, bottom, top]
# Elements of extent should be specified in data units which need to be calculated
# using the output of "Colour and Location Probe.py"


# Plot image
plt.imshow(rotate_image,origin='lower', extent=[-225.1, 73.4, -232, 215])
plt.colorbar(label="Image Intensity")

# Plot some blade outlines over the top
plt.plot(blade['axial'],blade['tan'],'k-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'k-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'k-',lw=3)
plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")

# Put a label on for shear stress
plt.annotate('Max.\nShear',color='white', xy=(-40.41,-33.56), xycoords='data',
                xytext=(-10,100), textcoords='data',
                arrowprops=dict(arrowstyle="->",color='white',linewidth=2)
                )

# Set some limits to crop the image
plt.xlim(-200,25)
plt.ylim(-225,125)

plt.savefig('Maxiumum_Wall_Shear_Point_Casing_with_blade.png', bbox_inches='tight',dpi=300)
plt.show()

