"""
Plot Data from Pictures and CFD Side by Side
"""

import matplotlib.pyplot as plt
import numpy as np
from scipy import ndimage
from scipy import interpolate
import math


# Set user variables here
voting_threshold = 20
cfd_file = 'TipClearance.csv'
viz_file = ("%d Threshold.txt" % voting_threshold)

# Read in blade geometry coordinates
blade = np.genfromtxt('bladegeometry.txt', delimiter=',', skip_header=1,
                     names=['axial', 'tan'])

# Read in data
data = np.genfromtxt('./CFD/%s' % cfd_file, delimiter=',', skip_header=7,
                     names=['axial', 'tan','radial','p','V','u','v','w'])
viz_data = np.genfromtxt('%s' % viz_file, delimiter=',', skip_header=1,
                     names=['axial', 'tan','alpha','u','v'])

print "Facts about the viz data"
print "Max alpha: %f" % viz_data['alpha'].max()
print "Min alpha: %f" % viz_data['alpha'].min()
print "Max viz u: %f" % viz_data['u'].max()
print "Min viz u: %f" % viz_data['u'].min()

# Process the CFD data a bit
x = data['axial']*1000
y = data['tan']*1000
cfd_angles = np.degrees(np.arctan(data['v']/data['u']))
phi = cfd_angles
cfd_V = data['p']

# Add periodic data (put in four sets to get good data - bit of a hack!)
# There is probably a better way of doing this.....
xl = np.append(x,x)
yl = np.append(y-191,y-382)
phil = np.append(phi,phi)
cfdVl = np.append(cfd_V,cfd_V)

xu = np.append(x,x)
yu = np.append(y+191,y)
phiu = np.append(phi,phi)
cfdVu = np.append(cfd_V,cfd_V)

x = np.append(xu,xl)
y = np.append(yu,yl)
phi = np.append(phiu,phil)
cfdV = np.append(cfdVu,cfdVl)

xi, yi = np.linspace(x.min(), x.max(), 1000), np.linspace(y.min(), y.max(), 1000)
xi, yi = np.meshgrid(xi, yi)
zi = interpolate.griddata((x, y), cfdV, (xi, yi), method='linear')

# *** Plot Number One ***
plt.imshow(zi, vmin=cfdV.min(), vmax=cfdV.max(), origin='lower',
           extent=[x.min(), x.max(), y.min(), y.max()],zorder=0)
plt.colorbar(label="Pressure / [Pa]")

# Plot some visualisation arrows
for i in viz_data:
        xf = i['axial']
        yf = i['tan']
        alpha = i['alpha']
        if (alpha > 90): alpha = alpha-180 # switch to angle convention in cascade
        dx = math.cos(math.radians(alpha))
        dy = math.sin(math.radians(alpha))
        # plt.arrow( x, y, dx, dy, **kwargs )
	plt.arrow( xf, yf, dx*10, dy*10, fc="g", ec="k",head_width=1.0, head_length=1.5 )
        # plt.text( x, y,int(alpha),size=4)
        

# Plot some blade outlines over the top
plt.plot(blade['axial'],blade['tan'],'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'g-',lw=3)
plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")
# Set some limits to crop the image
plt.xlim(-200,25)
plt.ylim(-225,125)

plt.savefig('%s_pressure_vizvectors.png' % voting_threshold, bbox_inches='tight',dpi=300)
#plt.show()
plt.close()


# *** Plot Number Two ***
# Generate a contour of compartive data for the cfd and viz
# To keep it simple we select the lower blade
# Range of x:  -200 to + 25
# Range of y: 0 to -191 (one blade pitch)

# Compare CFD Angles to the data

x_comp = []; y_comp = []; angles_comp = []
for i in viz_data:
        xf = i['axial']
        yf = i['tan']
        alpha = i['alpha']
        if (alpha > 90): alpha = alpha-180 # switch to angle convention in cascade
	if (xf > -200) and (xf < 25) and (yf > -191) and (yf < 0):
		x_comp.append(xf)
		y_comp.append(yf)
		angles_comp.append(alpha)
		# angle_diff = alpha-cfd_anglei
		#print xf,yf,alpha	
		# Find CFD Angle 
		# Calculate different
		# If so look up the CFD value at this point 
		# Store x,y and the error value

cfd_anglei = interpolate.griddata((x, y), phi, (x_comp, y_comp), method='linear')
angles_diff = angles_comp - cfd_anglei


# Fiddle with the data as our vectors don't differentiate +90 to -90
angles_diff2 = []
for i in angles_diff:
	if i > 90: 
		angles_diff2.append(i-180)
	elif i < -90:
		angles_diff2.append(i+180)
	else:
		angles_diff2.append(i)

# Do some sums on the error value (max, min, stddev)
print "Mean, std, max and min to follow:"		
print np.mean(angles_diff2)
print np.std(angles_diff2)
print np.max(angles_diff2)
print np.min(angles_diff2)






